==> vulkan-sdk-1.4.304.0-i686-1.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf dxc )
( cd usr/bin ; ln -sf dxc-3.7 dxc )
( cd usr/bin ; rm -rf glslangValidator )
( cd usr/bin ; ln -sf glslang glslangValidator )
( cd usr/bin ; rm -rf vulkanCapsViewer )
( cd usr/bin ; ln -sf vulkanCapsViewer-x11 vulkanCapsViewer )
( cd usr/lib ; rm -rf libSPIRV.so )
( cd usr/lib ; ln -sf libSPIRV.so.15 libSPIRV.so )
( cd usr/lib ; rm -rf libSPIRV.so.15 )
( cd usr/lib ; ln -sf libSPIRV.so.15.1.0 libSPIRV.so.15 )
( cd usr/lib ; rm -rf libSPVRemapper.so )
( cd usr/lib ; ln -sf libSPVRemapper.so.15 libSPVRemapper.so )
( cd usr/lib ; rm -rf libSPVRemapper.so.15 )
( cd usr/lib ; ln -sf libSPVRemapper.so.15.1.0 libSPVRemapper.so.15 )
( cd usr/lib ; rm -rf libglslang-default-resource-limits.so )
( cd usr/lib ; ln -sf libglslang-default-resource-limits.so.15 libglslang-default-resource-limits.so )
( cd usr/lib ; rm -rf libglslang-default-resource-limits.so.15 )
( cd usr/lib ; ln -sf libglslang-default-resource-limits.so.15.1.0 libglslang-default-resource-limits.so.15 )
( cd usr/lib ; rm -rf libglslang.so )
( cd usr/lib ; ln -sf libglslang.so.15 libglslang.so )
( cd usr/lib ; rm -rf libglslang.so.15 )
( cd usr/lib ; ln -sf libglslang.so.15.1.0 libglslang.so.15 )
( cd usr/lib ; rm -rf libshaderc_shared.so )
( cd usr/lib ; ln -sf libshaderc_shared.so.1 libshaderc_shared.so )
( cd usr/lib ; rm -rf libspirv-cross-c-shared.so )
( cd usr/lib ; ln -sf libspirv-cross-c-shared.so.0 libspirv-cross-c-shared.so )
( cd usr/lib ; rm -rf libspirv-cross-c-shared.so.0 )
( cd usr/lib ; ln -sf libspirv-cross-c-shared.so.0.64.0 libspirv-cross-c-shared.so.0 )
( cd usr/lib ; rm -rf libvulkan.so )
( cd usr/lib ; ln -sf libvulkan.so.1 libvulkan.so )
( cd usr/lib ; rm -rf libvulkan.so.1 )
( cd usr/lib ; ln -sf libvulkan.so.1.4.304 libvulkan.so.1 )

==> vulkan-sdk-1.4.313.0-i686-1.txz: install/doinst.sh <==
( cd usr/bin ; rm -rf dxc )
( cd usr/bin ; ln -sf dxc-3.7 dxc )
( cd usr/bin ; rm -rf glslangValidator )
( cd usr/bin ; ln -sf glslang glslangValidator )
( cd usr/bin ; rm -rf vulkanCapsViewer )
( cd usr/bin ; ln -sf vulkanCapsViewer-x11 vulkanCapsViewer )
( cd usr/lib ; rm -rf libSPIRV.so )
( cd usr/lib ; ln -sf libSPIRV.so.15 libSPIRV.so )
( cd usr/lib ; rm -rf libSPIRV.so.15 )
( cd usr/lib ; ln -sf libSPIRV.so.15.3.0 libSPIRV.so.15 )
( cd usr/lib ; rm -rf libSPVRemapper.so )
( cd usr/lib ; ln -sf libSPVRemapper.so.15 libSPVRemapper.so )
( cd usr/lib ; rm -rf libSPVRemapper.so.15 )
( cd usr/lib ; ln -sf libSPVRemapper.so.15.3.0 libSPVRemapper.so.15 )
( cd usr/lib ; rm -rf libglslang-default-resource-limits.so )
( cd usr/lib ; ln -sf libglslang-default-resource-limits.so.15 libglslang-default-resource-limits.so )
( cd usr/lib ; rm -rf libglslang-default-resource-limits.so.15 )
( cd usr/lib ; ln -sf libglslang-default-resource-limits.so.15.3.0 libglslang-default-resource-limits.so.15 )
( cd usr/lib ; rm -rf libglslang.so )
( cd usr/lib ; ln -sf libglslang.so.15 libglslang.so )
( cd usr/lib ; rm -rf libglslang.so.15 )
( cd usr/lib ; ln -sf libglslang.so.15.3.0 libglslang.so.15 )
( cd usr/lib ; rm -rf libopenxr_loader.so )
( cd usr/lib ; ln -sf libopenxr_loader.so.1 libopenxr_loader.so )
( cd usr/lib ; rm -rf libopenxr_loader.so.1 )
( cd usr/lib ; ln -sf libopenxr_loader.so.1.1.40 libopenxr_loader.so.1 )
( cd usr/lib ; rm -rf libshaderc_shared.so )
( cd usr/lib ; ln -sf libshaderc_shared.so.1 libshaderc_shared.so )
( cd usr/lib ; rm -rf libspirv-cross-c-shared.so )
( cd usr/lib ; ln -sf libspirv-cross-c-shared.so.0 libspirv-cross-c-shared.so )
( cd usr/lib ; rm -rf libspirv-cross-c-shared.so.0 )
( cd usr/lib ; ln -sf libspirv-cross-c-shared.so.0.65.0 libspirv-cross-c-shared.so.0 )
( cd usr/lib ; rm -rf libvulkan.so )
( cd usr/lib ; ln -sf libvulkan.so.1 libvulkan.so )
( cd usr/lib ; rm -rf libvulkan.so.1 )
( cd usr/lib ; ln -sf libvulkan.so.1.4.313 libvulkan.so.1 )
